helga-yelling
===========

Responds to yelling with yelling.

Shamelessy, but hopefully not illegally, stolen from `A Really Fun(tm) Hayt plugin <https://github.com/desert-planet/hayt/blob/master/scripts/loud.coffee>`_. Essentially encourages yelling because yells get saved and responded to with random yells it remembers.

License
-------

Copyright (c) 2016 Justin Caratzas

GPLv3 Licensed
